==> moodle-1.5-mysql.tgz: moodle/lang/vi_utf8/forum.php <==
<?php // $Id$ 
      // forum.php - created with Moodle 1.2 development (2003111400)


$string['addanewdiscussion'] = ' Thêm một chủ đề thảo luận mới';
$string['advancedsearch'] = 'Tìm kiếm nâng cao'; 
$string['addanewtopic'] = '  Thêm một chủ đề mới ';
$string['allowchoice'] = ' Cho phép tất cả mọi người lựa chọn ';
$string['allowdiscussions'] = ' Có thể một $a gửi bài viết lên diễn đàn ?';
$string['allowratings'] = ' Cho phép đánh giá ?';
$string['allowsdiscussions'] = ' Diễn đàn này cho phép tạo một chủ đề thảo luận.';
$string['anyfile'] = 'Bất kỳ file nào ';
$string['attachment'] = 'File đính kèm ';
$string['bynameondate'] = 'Bởi $a->name - $a->date';
$string['configcleanreadtime'] = 'Giờ của ngày để xoá các bài viết cũ từ bảng \'read\'.';
$string['configdisplaymode'] = ' Chế độ hiển thị mặc định cho các thảo luận khi không được đặt.';
$string['configenablerssfeeds'] = ' Sự chuyển đổi này cho phép lấy  các tin về theo chuẩn RSS đối với tất cả các diễn đàn. Bạn cũng cần lấy tin về bằng tay theo cấu hình của mỗi diễn đàn.';
$string['configlongpost'] = ' Bất kỳ bài viết nào vượt quá chiều dài này thì coi là dài.';
$string['configmanydiscussions'] = ' Số cuộc thảo luận tối đa hiển thị trong mỗi trang của diễn đàn ';
$string['configmaxbytes'] = ' Kích thước tối đa mặc định đối với tất cả các file đính kèm trên mỗi trang ';
$string['configreplytouser'] = ' Khi một bài viết được gửi mail, nó có chứa địa chỉ người gửi không để người nhận trả lời qua mail không qua diễn đàn? Thậm chí nếu đặt là \'Yes\' người dùng có thể cấu hình trong phần thông tin cá nhân để giữ email bí mật.';
$string['configshortpost'] = 'Bất kì bài viết nào nhỏ hơn kích thước này (không bao gồm HTML) được coi là ngắn.';
$string['couldnotadd'] = ' Không thể thêm bài viết của bạn  bởi vì có một lỗi không rõ ';
$string['couldnotdeleteratings'] = 'Xin lỗi, không thể xóa nó khi mọi người  đang xem nó ';
$string['couldnotdeletereplies'] = 'Xin lỗi không thể xóa nó khi mọi người đang gửi bài lên nó';
$string['couldnotupdate'] = ' Không thể cập nhật bài viết của bạn bởi vì có một lỗi không rõ ';
$string['delete'] = 'Xoá';
$string['deleteddiscussion'] = ' Chủ đề thảo luận bị xóa';
$string['deletedpost'] = ' bài viết bị xóa ';
$string['deletesure'] = 'Bạn có chắc chắn muốn xóa bài viết đó ?';
$string['digestmailheader'] = ' Đây là sự tóm tắt các bài viết mới hàng ngày từ  $a-> sitename các diễn đàn. Để thay đổi email diễn đàn đẹp hơn, đi tới $a->userprefs.';
$string['digestmailprefs'] = ' Hồ sơ cá nhân ';
$string['digestmailsubject'] = '$a: Phân loại diễn đàn';
$string['digestsentusers'] = 'Email phân loại thành công gửi tới $a người dùng.';
$string['discussion'] = ' Diễn đàn ';
$string['discussionmoved'] = ' Chủ đề này đã bị di chuyển tới  \'$a\'.';
$string['discussions'] = ' Số chủ đề ';
$string['discussionname'] = '  Tên cuộc thảo luận ';
$string['discussionsstartedby'] = ' Các cuộc thảo luận được tham gia bởi  $a';
$string['discussionsstartedbyrecent'] = ' Các cuộc thảo luận gần đây được tham gia bởi $a';
$string['discussthistopic'] = ' Thảo luận về chủ đề này ';
$string['eachuserforum'] = ' Mỗi người gửi lên  một chủ đề thảo luận ';
$string['edit'] = ' Chỉnh sửa';
$string['editing'] = ' Chỉnh sửa ';
$string['emptymessage'] = ' Có một số lỗi với bản bài viết của bạn. Có thể một  số chỗ trống bạn chưa điền hoặc File đính kèm quá lớn. Những thay đổi của bạn chưa được cất.';
$string['everyonecanchoose'] = ' Mọi người có thể chọn để đăng kí ';
$string['everyoneissubscribed'] = ' Mọi người được đăng kí diễn đàn này';
$string['existingsubscribers'] = ' những người đang đăng kí';
$string['forcesubscribe'] = ' Bắt buộc mọi người đăng kí ';
$string['forcesubscribeq'] = ' Bắt buộc mọi người đăng kí ?';
$string['forum'] = ' Diễn đàn';
$string['forumintro'] = ' Giới thiệu về diễn đàn';
$string['forumname'] = ' Tên  diễn đàn ';
$string['forums'] = 'Các diễn đàn';
$string['forumtype'] = ' Kiểu diễn đàn ';
$string['generalforum'] = ' Diễn đàn dành cho việc sử dụng thông thường ';
$string['generalforums'] = ' Các diễn đàn  ';
$string['inforum'] = 'trong $a';
$string['intronews'] = ' Các thông tin phổ biến và các thôn báo ';
$string['introsocial'] = ' Diễn đàn dành cho chat ';
$string['introteacher'] = 'Diễn đàn dành cho giáo viên nhận xét và thảo luận ';
$string['lastpost'] = '  Bài viết gần đây nhất ';
$string['learningforums'] = ' Các diễn đàn dành cho học tập';
$string['maxattachmentsize'] = 'Kích thước file đính kèm tối đa';
$string['maxtimehaspassed'] = 'Xin lỗi, thời gian chỉnh sửa bài viết ($a)đã hết !';
$string['message'] = 'Nội dung';
$string['modeflatnewestfirst'] = ' Lần gửi cuối cùng ';
$string['modeflatoldestfirst'] = ' Lần gửi đầu tiên ';
$string['modenested'] = ' Hiển thị phúc đáp theo kiểu  cấu trúc';
$string['modethreaded'] = ' Hiển thị phúc đáp một cách tuần tự';
$string['modulename'] = ' Diễn đàn';
$string['modulenameplural'] = 'Diễn đàn ';
$string['more'] = 'Đọc tiếp';
$string['movethisdiscussionto'] = ' Di chuyển cuộc thảo luận này tới ... ';
$string['namenews'] = 'Diễn đàn tin tức ';
$string['namesocial'] = ' Diễn đàn dành cho tập thể ';
$string['nameteacher'] = ' Diễn đàn dành cho giáo viên ';
$string['newforumposts'] = ' Bài viết mới của các diễn đàn ';
$string['nodiscussions'] = ' Chưa có chủ đề thảo luận nào trong diễn đàn này ';
$string['noguestpost'] = 'Xin lỗi,  khách không được phép gửi ';
$string['nomorepostscontaining'] = 'Không có các bài viết  \'$a\' được tìm thấy ';
$string['nonews'] = ' Chưa có tin tức nào được gửi';
$string['noposts'] = 'Chưa có bài viết nào';
$string['nopostscontaining'] = 'Không chứa đựng các bài viết \'$a\' cần tìm ';
$string['nosubscribers'] = ' Chưa có ai đăng ký diễn đàn  ';
$string['notingroup'] = 'Xin lỗi,  bạn cần  phải trở thành một thành viên của một nhóm để  tham gia diễn đàn này.';
$string['nownotsubscribed'] = '$a->name sẽ không nhận các bản copy của \'$a->forum\'  qua Email.';
$string['nowsubscribed'] = '$a->name sẽ nhận các bản copy của  \'$a->forum\' qua Email.';
$string['numposts'] = '$a bài viết ';
$string['olderdiscussions'] = ' Các cuộc thảo luận trước đây ';
$string['openmode0'] = ' Không có cuộc thảo luận , không có phúc đáp';
$string['openmode1'] = ' Không có các cuộc thảo luận nhưng có các phúc đáp ';
$string['openmode2'] = ' Có các cuộc thảo luận và các phúc đáp';
$string['parent'] = ' Xem bài được phúc đáp ';
$string['parentofthispost'] = ' Nguồn gốc của bài viết này';
$string['postadded'] = ' Bài viết của bạn được gửi thành công.<p>Bạn có $a để chỉnh sửa nó nếu bạn muốn thay đổi nó.';
$string['postincontext'] = 'Nhìn bài viết này trong ngữ cảnh';
$string['postmailinfo'] = ' Đây là một bản copy của phúc đáp được gửi lên trên  $a website.

Để trả lời thông qua website, nhấn chuột vào liên kết này:';
$string['postrating1'] = 'Mostly Separate Knowing ';
$string['postrating2'] = 'Tách rời và được kết nối ';
$string['postrating3'] = ' Mostly Connected Knowing';
$string['posts'] = ' Các bài viết';
$string['posttoforum'] = 'Gửi bài viết lên diễn đàn';
$string['postupdated'] = ' Bài viết được cập nhật';
$string['potentialsubscribers'] = ' Những người đăng kí tiềm năng ';
$string['processingpost'] = ' Xử lý bài viết $a';
$string['processingdigest'] = 'Xử lý phân loại Email đối với người dùng $a';
$string['prune'] = 'Tách';
$string['pruneheading'] = ' Chia cuộc thảo luận ra và di chuyển bài viết tới một  cuộc thảo luận mới ';
$string['prunedpost'] = ' Một cuộc thảo luận mới được tạo ra từ bài viết đó ';
$string['rate'] = 'Đánh giá';
$string['rating'] = 'Phân loại';
$string['ratingeveryone'] = ' Mọi người có thể bình luận về bài viết ';
$string['ratingno'] = ' Không có đánh giá ';
$string['ratingonlyteachers'] = 'Chỉ $a có thể đánh giá các bài viết';
$string['ratingpublic'] = '$a có thể xem điểm của mọi người';
$string['ratingpublicnot'] = '$a chỉ có thể xem điểm của mình';
$string['ratings'] = ' Các đánh giá ';
$string['ratingssaved'] = ' Các đánh giá lữu trữ ';
$string['ratingsuse'] = ' Sử dụng mọi đánh giá ';
$string['ratingtime'] = '  Hạn chế đánh giá trong khoảng thời gian .';
$string['re'] = 'Trả lời:';
$string['readtherest'] = 'Đọc phần còn lại của chủ đề';
$string['replies'] = ' Phúc đáp ';
$string['repliesmany'] = '$a  phúc đáp ';
$string['repliesone'] = '$a phúc đáp từ trước tới giờ';
$string['reply'] = ' Phúc đáp';
$string['replyforum'] = ' Phúc đáp diễn đàn này';
$string['rsssubscriberssdiscussions'] = ' Hiển thị thông tin theo chuẩn RSS đối với  \'$a\' các thảo luận';
$string['rsssubscriberssposts'] = ' Hiển thị các thông tin theo chuẩn RSS đối với  \'$a\' các bài viết';
$string['search'] = 'Các diễn đàn';
$string['searchforums'] = ' Tìm kiếm ';
$string['searcholderposts'] = ' Tìm kiếm các bài viết cũ hơn...';
$string['searchdatefrom'] = 'Các bài viết phải mới hơn';
$string['searchforumintro'] = 'Hãy điền các từ tìm kiếm vào một hoặc nhiều hơn các trường dưới đây:';
$string['searchfullwords'] = 'Các từ này phải được xuất hiện như toàn bộ các từ';
$string['searchnotwords'] = 'Các từ này không bao gồm';
$string['searchphrase'] = 'Cụm từ chính xác này phải được xuất hiện trong bài viết';
$string['searchsubject'] = 'Các từ này phải xuất hiện trong chủ đề';
$string['searchuser'] = 'Tên này phải trùng với tên tác giả';
$string['searchuserid'] = 'Moodle ID của tác giả';
$string['searchwords'] = 'Các từ này có thể xuất hiện đâu đó trong bài viết ';
$string['searcholderposts'] = 'Tìm các bài viết cũ...';
$string['searchwhichforums'] = 'Chọn diễn đàn nào để tìm kiếm';
$string['searchresults'] = ' Các kết quả tìm kiếm ';
$string['sendinratings'] = ' Gửi các đánh giá mới nhất của tôi ';
$string['showsubscribers'] = ' Xem / chỉnh sửa những người đăng ký hiện tại ';
$string['singleforum'] = 'Một cuộc thảo luận đơn giản ';
$string['startedby'] = ' tham  gia bởi';
$string['subject'] = ' Tiêu đề ';
$string['subscribe'] = ' Đăng ký tới diễn đàn này ';
$string['subscribeall'] = ' Tất cả mọi người đều đăng ký tới diễn đàn này';
$string['subscribed'] = ' Đăng ký';
$string['subscribenone'] = ' Hủy đăng ký mọi người từ diễn đàn này ';
$string['subscribers'] = ' Những người đăng ký ';
$string['subscribersto'] = 'Những người đăng ký tới \'$a\'';
$string['subscribestart'] = 'Gửi các bản copy qua Email ';
$string['subscribestop'] = ' Không gửi các bản copy qua Email ';
$string['subscription'] = 'Đăng ký';
$string['subscriptions'] = ' Đăng ký ';
$string['unsubscribe'] = 'Hủy đăng ký tham gia diễn đàn này';
$string['unsubscribed'] = 'Hủy đăng ký tham gia';
$string['unsubscribeshort'] = 'Hủy đăng ký tham gia';
$string['yesinitially'] = 'Đồng ý, ban đầu';
$string['yesforever'] = 'Đông ý, mãi mãi';
$string['youratedthis'] = 'Bạn đánh giá ';
$string['yournewtopic'] = 'Chủ đề thảo luận mới ';
$string['yourreply'] = ' Bài phúc đáp của bạn';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/vi_utf8/forum.php <==
<?php // $Id$ 
      // forum.php - created with Moodle 1.2 development (2003111400)


$string['addanewdiscussion'] = ' Thêm một chủ đề thảo luận mới';
$string['advancedsearch'] = 'Tìm kiếm nâng cao'; 
$string['addanewtopic'] = '  Thêm một chủ đề mới ';
$string['allowchoice'] = ' Cho phép tất cả mọi người lựa chọn ';
$string['allowdiscussions'] = ' Có thể một $a gửi bài viết lên diễn đàn ?';
$string['allowratings'] = ' Cho phép đánh giá ?';
$string['allowsdiscussions'] = ' Diễn đàn này cho phép tạo một chủ đề thảo luận.';
$string['anyfile'] = 'Bất kỳ file nào ';
$string['attachment'] = 'File đính kèm ';
$string['bynameondate'] = 'Bởi $a->name - $a->date';
$string['configcleanreadtime'] = 'Giờ của ngày để xoá các bài viết cũ từ bảng \'read\'.';
$string['configdisplaymode'] = ' Chế độ hiển thị mặc định cho các thảo luận khi không được đặt.';
$string['configenablerssfeeds'] = ' Sự chuyển đổi này cho phép lấy  các tin về theo chuẩn RSS đối với tất cả các diễn đàn. Bạn cũng cần lấy tin về bằng tay theo cấu hình của mỗi diễn đàn.';
$string['configlongpost'] = ' Bất kỳ bài viết nào vượt quá chiều dài này thì coi là dài.';
$string['configmanydiscussions'] = ' Số cuộc thảo luận tối đa hiển thị trong mỗi trang của diễn đàn ';
$string['configmaxbytes'] = ' Kích thước tối đa mặc định đối với tất cả các file đính kèm trên mỗi trang ';
$string['configreplytouser'] = ' Khi một bài viết được gửi mail, nó có chứa địa chỉ người gửi không để người nhận trả lời qua mail không qua diễn đàn? Thậm chí nếu đặt là \'Yes\' người dùng có thể cấu hình trong phần thông tin cá nhân để giữ email bí mật.';
$string['configshortpost'] = 'Bất kì bài viết nào nhỏ hơn kích thước này (không bao gồm HTML) được coi là ngắn.';
$string['couldnotadd'] = ' Không thể thêm bài viết của bạn  bởi vì có một lỗi không rõ ';
$string['couldnotdeleteratings'] = 'Xin lỗi, không thể xóa nó khi mọi người  đang xem nó ';
$string['couldnotdeletereplies'] = 'Xin lỗi không thể xóa nó khi mọi người đang gửi bài lên nó';
$string['couldnotupdate'] = ' Không thể cập nhật bài viết của bạn bởi vì có một lỗi không rõ ';
$string['delete'] = 'Xoá';
$string['deleteddiscussion'] = ' Chủ đề thảo luận bị xóa';
$string['deletedpost'] = ' bài viết bị xóa ';
$string['deletesure'] = 'Bạn có chắc chắn muốn xóa bài viết đó ?';
$string['digestmailheader'] = ' Đây là sự tóm tắt các bài viết mới hàng ngày từ  $a-> sitename các diễn đàn. Để thay đổi email diễn đàn đẹp hơn, đi tới $a->userprefs.';
$string['digestmailprefs'] = ' Hồ sơ cá nhân ';
$string['digestmailsubject'] = '$a: Phân loại diễn đàn';
$string['digestsentusers'] = 'Email phân loại thành công gửi tới $a người dùng.';
$string['discussion'] = ' Diễn đàn ';
$string['discussionmoved'] = ' Chủ đề này đã bị di chuyển tới  \'$a\'.';
$string['discussions'] = ' Số chủ đề ';
$string['discussionname'] = '  Tên cuộc thảo luận ';
$string['discussionsstartedby'] = ' Các cuộc thảo luận được bắt đầu bởi  $a';
$string['discussionsstartedbyrecent'] = ' Các cuộc thảo luận gần đây được bắt đầu bởi $a';
$string['discussthistopic'] = ' Thảo luận về chủ đề này ';
$string['eachuserforum'] = ' Mỗi người gửi lên  một chủ đề thảo luận ';
$string['edit'] = ' Chỉnh sửa';
$string['editing'] = ' Chỉnh sửa ';
$string['emptymessage'] = ' Có một số lỗi với bản bài viết của bạn. Có thể một  số chỗ trống bạn chưa điền hoặc File đính kèm quá lớn. Những thay đổi của bạn chưa được cất.';
$string['everyonecanchoose'] = ' Mọi người có thể chọn để đăng kí ';
$string['everyoneissubscribed'] = ' Mọi người được đăng kí diễn đàn này';
$string['existingsubscribers'] = ' những người đang đăng kí';
$string['forcesubscribe'] = ' Bắt buộc mọi người đăng kí ';
$string['forcesubscribeq'] = ' Bắt buộc mọi người đăng kí ?';
$string['forum'] = ' Diễn đàn';
$string['forumintro'] = ' Giới thiệu về diễn đàn';
$string['forumname'] = ' Tên  diễn đàn ';
$string['forums'] = 'Các diễn đàn';
$string['forumtype'] = ' Kiểu diễn đàn ';
$string['generalforum'] = ' Diễn đàn dành cho việc sử dụng thông thường ';
$string['generalforums'] = ' Các diễn đàn  ';
$string['inforum'] = 'trong $a';
$string['intronews'] = ' Các thông tin phổ biến và các thôn báo ';
$string['introsocial'] = ' Diễn đàn dành cho chat ';
$string['introteacher'] = 'Diễn đàn dành cho giáo viên nhận xét và thảo luận ';
$string['lastpost'] = '  Bài viết gần đây nhất ';
$string['learningforums'] = ' Các diễn đàn dành cho học tập';
$string['maxattachmentsize'] = 'Kích thước file đính kèm tối đa';
$string['maxtimehaspassed'] = 'Xin lỗi, thời gian chỉnh sửa bài viết ($a)đã hết !';
$string['message'] = 'Nội dung';
$string['modeflatnewestfirst'] = ' Lần gửi cuối cùng ';
$string['modeflatoldestfirst'] = ' Lần gửi đầu tiên ';
$string['modenested'] = ' Hiển thị phúc đáp theo kiểu  cấu trúc';
$string['modethreaded'] = ' Hiển thị phúc đáp một cách tuần tự';
$string['modulename'] = ' Diễn đàn';
$string['modulenameplural'] = 'Diễn đàn ';
$string['more'] = 'Đọc tiếp';
$string['movethisdiscussionto'] = ' Di chuyển cuộc thảo luận này tới ... ';
$string['namenews'] = 'Diễn đàn tin tức ';
$string['namesocial'] = ' Diễn đàn dành cho tập thể ';
$string['nameteacher'] = ' Diễn đàn dành cho giáo viên ';
$string['newforumposts'] = ' Bài viết mới của các diễn đàn ';
$string['nodiscussions'] = ' Chưa có chủ đề thảo luận nào trong diễn đàn này ';
$string['noguestpost'] = 'Xin lỗi,  khách không được phép gửi ';
$string['nomorepostscontaining'] = 'Không có các bài viết  \'$a\' được tìm thấy ';
$string['nonews'] = ' Chưa có tin tức nào được gửi';
$string['noposts'] = 'Chưa có bài viết nào';
$string['nopostscontaining'] = 'Không chứa đựng các bài viết \'$a\' cần tìm ';
$string['nosubscribers'] = ' Chưa có ai đăng ký diễn đàn  ';
$string['notingroup'] = 'Xin lỗi,  bạn cần  phải trở thành một thành viên của một nhóm để  tham gia diễn đàn này.';
$string['nownotsubscribed'] = '$a->name sẽ không nhận các bản copy của \'$a->forum\'  qua Email.';
$string['nowsubscribed'] = '$a->name sẽ nhận các bản copy của  \'$a->forum\' qua Email.';
$string['numposts'] = '$a bài viết ';
$string['olderdiscussions'] = ' Các cuộc thảo luận trước đây ';
$string['openmode0'] = ' Không có cuộc thảo luận , không có phúc đáp';
$string['openmode1'] = ' Không có các cuộc thảo luận nhưng có các phúc đáp ';
$string['openmode2'] = ' Có các cuộc thảo luận và các phúc đáp';
$string['parent'] = ' Xem bài được phúc đáp ';
$string['parentofthispost'] = ' Nguồn gốc của bài viết này';
$string['postadded'] = ' Bài viết của bạn được gửi thành công.<p>Bạn có $a để chỉnh sửa nó nếu bạn muốn thay đổi nó.';
$string['postincontext'] = 'Nhìn bài viết này trong ngữ cảnh';
$string['postmailinfo'] = ' Đây là một bản copy của phúc đáp được gửi lên trên  $a website.

Để trả lời thông qua website, nhấn chuột vào liên kết này:';
$string['postrating1'] = 'Mostly Separate Knowing ';
$string['postrating2'] = 'Tách rời và được kết nối ';
$string['postrating3'] = ' Mostly Connected Knowing';
$string['posts'] = ' Các bài viết';
$string['posttoforum'] = 'Gửi bài viết lên diễn đàn';
$string['postupdated'] = ' Bài viết được cập nhật';
$string['potentialsubscribers'] = ' Những người đăng kí tiềm năng ';
$string['processingpost'] = ' Xử lý bài viết $a';
$string['processingdigest'] = 'Xử lý phân loại Email đối với người dùng $a';
$string['prune'] = 'Tách';
$string['pruneheading'] = ' Chia cuộc thảo luận ra và di chuyển bài viết tới một  cuộc thảo luận mới ';
$string['prunedpost'] = ' Một cuộc thảo luận mới được tạo ra từ bài viết đó ';
$string['rate'] = 'Đánh giá';
$string['rating'] = 'Phân loại';
$string['ratingeveryone'] = ' Mọi người có thể bình luận về bài viết ';
$string['ratingno'] = ' Không có đánh giá ';
$string['ratingonlyteachers'] = 'Chỉ $a có thể đánh giá các bài viết';
$string['ratingpublic'] = '$a có thể xem điểm của mọi người';
$string['ratingpublicnot'] = '$a chỉ có thể xem điểm của mình';
$string['ratings'] = ' Các đánh giá ';
$string['ratingssaved'] = ' Các đánh giá lữu trữ ';
$string['ratingsuse'] = ' Sử dụng mọi đánh giá ';
$string['ratingtime'] = '  Hạn chế đánh giá trong khoảng thời gian .';
$string['re'] = 'Trả lời:';
$string['readtherest'] = 'Đọc phần còn lại của chủ đề';
$string['replies'] = ' Phúc đáp ';
$string['repliesmany'] = '$a  phúc đáp ';
$string['repliesone'] = '$a phúc đáp từ trước tới giờ';
$string['reply'] = ' Phúc đáp';
$string['replyforum'] = ' Phúc đáp diễn đàn này';
$string['rsssubscriberssdiscussions'] = ' Hiển thị thông tin theo chuẩn RSS đối với  \'$a\' các thảo luận';
$string['rsssubscriberssposts'] = ' Hiển thị các thông tin theo chuẩn RSS đối với  \'$a\' các bài viết';
$string['search'] = 'Các diễn đàn';
$string['searchforums'] = ' Tìm kiếm ';
$string['searcholderposts'] = ' Tìm kiếm các bài viết cũ hơn...';
$string['searchdatefrom'] = 'Các bài viết phải mới hơn';
$string['searchforumintro'] = 'Hãy điền các từ tìm kiếm vào một hoặc nhiều hơn các trường dưới đây:';
$string['searchfullwords'] = 'Các từ này phải được xuất hiện như toàn bộ các từ';
$string['searchnotwords'] = 'Các từ này không bao gồm';
$string['searchphrase'] = 'Cụm từ chính xác này phải được xuất hiện trong bài viết';
$string['searchsubject'] = 'Các từ này phải xuất hiện trong chủ đề';
$string['searchuser'] = 'Tên này phải trùng với tên tác giả';
$string['searchuserid'] = 'Moodle ID của tác giả';
$string['searchwords'] = 'Các từ này có thể xuất hiện đâu đó trong bài viết ';
$string['searcholderposts'] = 'Tìm các bài viết cũ...';
$string['searchwhichforums'] = 'Chọn diễn đàn nào để tìm kiếm';
$string['searchresults'] = ' Các kết quả tìm kiếm ';
$string['sendinratings'] = ' Gửi các đánh giá mới nhất của tôi ';
$string['showsubscribers'] = ' Xem / chỉnh sửa những người đăng ký hiện tại ';
$string['singleforum'] = 'Một cuộc thảo luận đơn giản ';
$string['startedby'] = ' tham  gia bởi';
$string['subject'] = ' Tiêu đề ';
$string['subscribe'] = ' Đăng ký tới diễn đàn này ';
$string['subscribeall'] = ' Tất cả mọi người đều đăng ký tới diễn đàn này';
$string['subscribed'] = ' Đăng ký';
$string['subscribenone'] = ' Hủy đăng ký mọi người từ diễn đàn này ';
$string['subscribers'] = ' Những người đăng ký ';
$string['subscribersto'] = 'Những người đăng ký tới \'$a\'';
$string['subscribestart'] = 'Gửi các bản copy qua Email ';
$string['subscribestop'] = ' Không gửi các bản copy qua Email ';
$string['subscription'] = 'Đăng ký';
$string['subscriptions'] = ' Đăng ký ';
$string['unsubscribe'] = 'Hủy đăng ký tham gia diễn đàn này';
$string['unsubscribed'] = 'Hủy đăng ký tham gia';
$string['unsubscribeshort'] = 'Hủy đăng ký tham gia';
$string['yesinitially'] = 'Đồng ý, ban đầu';
$string['yesforever'] = 'Đông ý, mãi mãi';
$string['youratedthis'] = 'Bạn đánh giá ';
$string['yournewtopic'] = 'Chủ đề thảo luận mới ';
$string['yourreply'] = ' Bài phúc đáp của bạn';

?>
